Partial changes and fixup. 
Removed reset.c and added copyright headers.

Signed-off-by: Ronald G. Minnich <rminnich@gmail.com>

Index: src/mainboard/pcengines/alix1c/Config.lb
===================================================================
--- src/mainboard/pcengines/alix1c/Config.lb	(revision 2765)
+++ src/mainboard/pcengines/alix1c/Config.lb	(working copy)
@@ -1,4 +1,23 @@
 ##
+## This file is part of the LinuxBIOS project.
+##
+## Copyright (C) 2006-2007 Ronald G. Minnich <rminnich@gmail.com>
+##
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+##
+##
 ## Compute the location and size of where this firmware image
 ## (linuxBIOS plus bootloader) will live in the boot rom chip.
 ##
Index: src/mainboard/pcengines/alix1c/reset.c
===================================================================
--- src/mainboard/pcengines/alix1c/reset.c	(revision 2764)
+++ src/mainboard/pcengines/alix1c/reset.c	(working copy)
@@ -1,43 +0,0 @@
-#if 0
-//#include "arch/romcc_io.h"
-#include <arch/io.h>
-
-typedef unsigned device_t;
-
-#define PCI_DEV(BUS, DEV, FN) ( \
-	(((BUS) & 0xFF) << 16) | \
-	(((DEV) & 0x1f) << 11) | \
-	(((FN)  & 0x7) << 8))
-
-static void pci_write_config8(device_t dev, unsigned where, unsigned char value)
-{
-        unsigned addr;
-        addr = dev | where;
-        outl(0x80000000 | (addr & ~3), 0xCF8);
-        outb(value, 0xCFC + (addr & 3));
-}
-
-static void pci_write_config32(device_t dev, unsigned where, unsigned value)
-{
-	unsigned addr;
-        addr = dev | where;
-        outl(0x80000000 | (addr & ~3), 0xCF8);
-        outl(value, 0xCFC);
-}
-
-static unsigned pci_read_config32(device_t dev, unsigned where)
-{
-	unsigned addr;
-        addr = dev | where;
-        outl(0x80000000 | (addr & ~3), 0xCF8);
-        return inl(0xCFC);
-}
-
-#include "../../../northbridge/amd/amdk8/reset_test.c"
-
-void hard_reset(void)
-{
-	set_bios_reset();
-	pci_write_config8(PCI_DEV(1, 0x04, 0), 0x47, 1);
-}
-#endif
Index: src/mainboard/pcengines/alix1c/Options.lb
===================================================================
--- src/mainboard/pcengines/alix1c/Options.lb	(revision 2765)
+++ src/mainboard/pcengines/alix1c/Options.lb	(working copy)
@@ -1,3 +1,26 @@
+##
+## This file is part of the LinuxBIOS project.
+##
+## Copyright (C) 2006-2007 Ronald G. Minnich <rminnich@gmail.com>
+##
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+##
+##
+## Compute the location and size of where this firmware image
+## (linuxBIOS plus bootloader) will live in the boot rom chip.
+##
 uses HAVE_MP_TABLE
 uses HAVE_PIRQ_TABLE
 uses USE_FALLBACK_IMAGE
@@ -83,7 +106,7 @@
 ## Build code to export a programmable irq routing table
 ##
 default HAVE_PIRQ_TABLE=1
-default IRQ_SLOT_COUNT=6
+default IRQ_SLOT_COUNT=9
 #object irq_tables.o
 
 ##
Index: src/mainboard/pcengines/alix1c/chip.h
===================================================================
--- src/mainboard/pcengines/alix1c/chip.h	(revision 2765)
+++ src/mainboard/pcengines/alix1c/chip.h	(working copy)
@@ -1,3 +1,21 @@
+/*
+ * This file is part of the LinuxBIOS project.
+ *
+ * Copyright (C) 2007 Advanced Micro Devices, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
 extern struct chip_operations mainboard_pcengines_alix1c_ops;
 
 struct mainboard_pcengines_alix1c_config {
Index: src/mainboard/pcengines/alix1c/mainboard.c
===================================================================
--- src/mainboard/pcengines/alix1c/mainboard.c	(revision 2765)
+++ src/mainboard/pcengines/alix1c/mainboard.c	(working copy)
@@ -1,3 +1,21 @@
+/*
+ * This file is part of the LinuxBIOS project.
+ *
+ * Copyright (C) 2007 Advanced Micro Devices, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
 #include <console/console.h>
 #include <device/device.h>
 #include <device/pci.h>
@@ -148,7 +166,7 @@
 }
 
 struct chip_operations mainboard_pcengines_alix1c_ops = {
-	CHIP_NAME("PC ENGINES  ALIX1C Mainboard")
+	CHIP_NAME("PC ENGINES  ALIX1.C Mainboard")
         .enable_dev = enable_dev,
 };
 
Index: src/mainboard/pcengines/alix1c/cache_as_ram_auto.c
===================================================================
--- src/mainboard/pcengines/alix1c/cache_as_ram_auto.c	(revision 2765)
+++ src/mainboard/pcengines/alix1c/cache_as_ram_auto.c	(working copy)
@@ -1,3 +1,21 @@
+/*
+ * This file is part of the LinuxBIOS project.
+ *
+ * Copyright (C) 2007 Advanced Micro Devices, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
 #define ASSEMBLY 1
 
 #include <stdint.h>

Index: src/mainboard/pcengines/alix1c/irq_tables.c
===================================================================
--- src/mainboard/pcengines/alix1c/irq_tables.c	(revision 2765)
+++ src/mainboard/pcengines/alix1c/irq_tables.c	(working copy)
@@ -44,7 +44,7 @@
 const struct irq_routing_table intel_irq_routing_table = {
 	PIRQ_SIGNATURE,  /* u32 signature */
 	PIRQ_VERSION,    /* u16 version   */
-	32+16*9,	 /* There can be total 9 devices on the bus */
+	32+16*IRQ_SLOT_COUNT,	 /* There can be total IRQ_SLOT_COUNT devices on the bus */
 	0x00,		 /* Where the interrupt router lies (bus) */
 	(0x0f<<3)|0x0,   /* Where the interrupt router lies (dev) */
 	0,		 /* IRQs devoted exclusively to PCI usage */